@@ -9,6 +9,9 @@
 #include <QMenuBar>
 #include "playlist.h"
 #include "grooveprogressbar.h"
+#include "topbar.h"
+#include "vkb.h"
+#include "bottombar.h"
 
 class groove : public QWidget
 {
@@ -26,10 +29,13 @@ public slots:
     void stop();
     void moreB();
     void orientationChanged();
+    void performSearch(QString);
 private slots:
     void progressUpdate(int,qint64,qint64);
     void addSongPlaylist();
+    void showOthers();
 private:
+    bottomBar *bBar;
     sPlayer *player;
     QMenuBar *mBar;
     QPushButton *sMethod;
@@ -43,7 +49,6 @@ private:
     QMaemo5Rotator *rot;
 #endif
     playlist *pl;
-    grooveProgressBar *pd;
 
 };
 
